MILLISECS_IN_SECS = 1000
NANOSECS_IN_MILLISECS = 1000000

TIMESTAMP_LEN = 6
RANDOMNESS_LEN = 10
BYTES_LEN = TIMESTAMP_LEN + RANDOMNESS_LEN

TIMESTAMP_REPR_LEN = 10
RANDOMNESS_REPR_LEN = 16
REPR_LEN = TIMESTAMP_REPR_LEN + RANDOMNESS_REPR_LEN

INT_REPR_LEN = 37

HEX_REPR_LEN = 32
UUID_REPR_LEN = 36  # UUID with dash-separated segments
